==> jc-1.4.0.tar.gz: javax/swing/text/StyledEditorKit__24FontSizeAction.h <==
// public class javax.swing.text.StyledEditorKit$FontSizeAction

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class f02353a2de7b0e85 javax_swing_AbstractAction
// @dep_class 22620c16fa07db1b javax_swing_text_StyledEditorKit__24FontSizeAction
// @dep_class 269e09938263c482 javax_swing_text_StyledEditorKit__24StyledTextAction
// @dep_class ebc1c295cb90fd47 javax_swing_text_TextAction

// header file dependencies
// @dep_header javax_swing_text_StyledEditorKit__24StyledTextAction

#include "javax/swing/text/StyledEditorKit__24StyledTextAction.h"

#ifndef _JC_javax_swing_text_StyledEditorKit__24FontSizeAction_H_
#define _JC_javax_swing_text_StyledEditorKit__24FontSizeAction_H_

// Forward structure declarations
struct _jc_java_awt_event_ActionEvent$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_javax_swing_text_StyledEditorKit__24FontSizeAction$sub_refs	_jc_javax_swing_text_StyledEditorKit__24FontSizeAction$sub_refs;
typedef struct _jc_javax_swing_text_StyledEditorKit__24FontSizeAction$sub_nonrefs	_jc_javax_swing_text_StyledEditorKit__24FontSizeAction$sub_nonrefs;
typedef struct _jc_javax_swing_text_StyledEditorKit__24FontSizeAction$refs	_jc_javax_swing_text_StyledEditorKit__24FontSizeAction$refs;
typedef struct _jc_javax_swing_text_StyledEditorKit__24FontSizeAction$nonrefs	_jc_javax_swing_text_StyledEditorKit__24FontSizeAction$nonrefs;
typedef struct _jc_javax_swing_text_StyledEditorKit__24FontSizeAction$object	_jc_javax_swing_text_StyledEditorKit__24FontSizeAction$object;

typedef const struct _jc_javax_swing_text_StyledEditorKit__24FontSizeAction$vmethods	_jc_javax_swing_text_StyledEditorKit__24FontSizeAction$vmethods;
typedef const struct _jc_javax_swing_text_StyledEditorKit__24FontSizeAction$vtable	_jc_javax_swing_text_StyledEditorKit__24FontSizeAction$vtable;
typedef const struct _jc_javax_swing_text_StyledEditorKit__24FontSizeAction$vtype	_jc_javax_swing_text_StyledEditorKit__24FontSizeAction$vtype;

// Constructors
extern void _jc_javax_swing_text_StyledEditorKit__24FontSizeAction$method$_init$8b03e78e1eb3b29e(_jc_env *, struct _jc_javax_swing_text_StyledEditorKit__24FontSizeAction$object *, struct _jc_java_lang_String$object *, jint);

// Virtual methods
extern void _jc_javax_swing_text_StyledEditorKit__24FontSizeAction$method$actionPerformed$9046a9754e643ffd(_jc_env *, struct _jc_javax_swing_text_StyledEditorKit__24FontSizeAction$object *, struct _jc_java_awt_event_ActionEvent$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_text_StyledEditorKit__24FontSizeAction$method_info$actionPerformed$9046a9754e643ffd;

// Virtual methods structure
struct _jc_javax_swing_text_StyledEditorKit__24FontSizeAction$vmethods {
	void	(*actionPerformed$9046a9754e643ffd)(_jc_env *, struct _jc_javax_swing_text_StyledEditorKit__24FontSizeAction$object *, struct _jc_java_awt_event_ActionEvent$object *);
};

// Vtable
struct _jc_javax_swing_text_StyledEditorKit__24FontSizeAction$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_AbstractAction$vmethods	javax_swing_AbstractAction;
	_jc_javax_swing_text_TextAction$vmethods	javax_swing_text_TextAction;
	_jc_javax_swing_text_StyledEditorKit__24StyledTextAction$vmethods	javax_swing_text_StyledEditorKit__24StyledTextAction;
	_jc_javax_swing_text_StyledEditorKit__24FontSizeAction$vmethods	javax_swing_text_StyledEditorKit__24FontSizeAction;
};

// Vtype
struct _jc_javax_swing_text_StyledEditorKit__24FontSizeAction$vtype {
	_jc_type			type;
	_jc_javax_swing_text_StyledEditorKit__24FontSizeAction$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_text_StyledEditorKit__24FontSizeAction$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_text_StyledEditorKit__24FontSizeAction$refs {
    _jc_javax_swing_text_StyledEditorKit__24FontSizeAction$sub_refs	javax_swing_text_StyledEditorKit__24FontSizeAction;
    _jc_javax_swing_text_StyledEditorKit__24StyledTextAction$sub_refs	javax_swing_text_StyledEditorKit__24StyledTextAction;
    _jc_javax_swing_text_TextAction$sub_refs	javax_swing_text_TextAction;
    _jc_javax_swing_AbstractAction$sub_refs	javax_swing_AbstractAction;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_text_StyledEditorKit__24FontSizeAction$sub_nonrefs {
	jint	size;
};

// Non-reference instance fields (object)
struct _jc_javax_swing_text_StyledEditorKit__24FontSizeAction$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_AbstractAction$sub_nonrefs	javax_swing_AbstractAction;
    _jc_javax_swing_text_TextAction$sub_nonrefs	javax_swing_text_TextAction;
    _jc_javax_swing_text_StyledEditorKit__24StyledTextAction$sub_nonrefs	javax_swing_text_StyledEditorKit__24StyledTextAction;
    _jc_javax_swing_text_StyledEditorKit__24FontSizeAction$sub_nonrefs	javax_swing_text_StyledEditorKit__24FontSizeAction;
};

// Object instance structure
struct _jc_javax_swing_text_StyledEditorKit__24FontSizeAction$object {
	_jc_javax_swing_text_StyledEditorKit__24FontSizeAction$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_text_StyledEditorKit__24FontSizeAction$vtype	*vtype;
	_jc_javax_swing_text_StyledEditorKit__24FontSizeAction$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_text_StyledEditorKit__24FontSizeAction$vtype _jc_javax_swing_text_StyledEditorKit__24FontSizeAction$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_text_StyledEditorKit__24FontSizeAction, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_text_StyledEditorKit__24FontSizeAction$class_object;

#endif	/* _JC_javax_swing_text_StyledEditorKit__24FontSizeAction_H_ */

==> jc-1.4.5.tar.gz: javax/swing/text/StyledEditorKit__24FontSizeAction.h <==
// public class javax.swing.text.StyledEditorKit$FontSizeAction

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class f02353a2de7b0e85 javax_swing_AbstractAction
// @dep_class 22620c16fa07db1b javax_swing_text_StyledEditorKit__24FontSizeAction
// @dep_class 269e09938263c482 javax_swing_text_StyledEditorKit__24StyledTextAction
// @dep_class ebc1c295cb90fd47 javax_swing_text_TextAction

// header file dependencies
// @dep_header javax_swing_text_StyledEditorKit__24StyledTextAction

#include "javax/swing/text/StyledEditorKit__24StyledTextAction.h"

#ifndef _JC_javax_swing_text_StyledEditorKit__24FontSizeAction_H_
#define _JC_javax_swing_text_StyledEditorKit__24FontSizeAction_H_

// Forward structure declarations
struct _jc_java_awt_event_ActionEvent$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_javax_swing_text_StyledEditorKit__24FontSizeAction$sub_refs	_jc_javax_swing_text_StyledEditorKit__24FontSizeAction$sub_refs;
typedef struct _jc_javax_swing_text_StyledEditorKit__24FontSizeAction$sub_nonrefs	_jc_javax_swing_text_StyledEditorKit__24FontSizeAction$sub_nonrefs;
typedef struct _jc_javax_swing_text_StyledEditorKit__24FontSizeAction$refs	_jc_javax_swing_text_StyledEditorKit__24FontSizeAction$refs;
typedef struct _jc_javax_swing_text_StyledEditorKit__24FontSizeAction$nonrefs	_jc_javax_swing_text_StyledEditorKit__24FontSizeAction$nonrefs;
typedef struct _jc_javax_swing_text_StyledEditorKit__24FontSizeAction$object	_jc_javax_swing_text_StyledEditorKit__24FontSizeAction$object;

typedef const struct _jc_javax_swing_text_StyledEditorKit__24FontSizeAction$vmethods	_jc_javax_swing_text_StyledEditorKit__24FontSizeAction$vmethods;
typedef const struct _jc_javax_swing_text_StyledEditorKit__24FontSizeAction$vtable	_jc_javax_swing_text_StyledEditorKit__24FontSizeAction$vtable;
typedef const struct _jc_javax_swing_text_StyledEditorKit__24FontSizeAction$vtype	_jc_javax_swing_text_StyledEditorKit__24FontSizeAction$vtype;

// Constructors
extern void _jc_javax_swing_text_StyledEditorKit__24FontSizeAction$method$_init$8b03e78e1eb3b29e(_jc_env *, struct _jc_javax_swing_text_StyledEditorKit__24FontSizeAction$object *, struct _jc_java_lang_String$object *, jint) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_javax_swing_text_StyledEditorKit__24FontSizeAction$method$actionPerformed$9046a9754e643ffd(_jc_env *, struct _jc_javax_swing_text_StyledEditorKit__24FontSizeAction$object *, struct _jc_java_awt_event_ActionEvent$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_text_StyledEditorKit__24FontSizeAction$method_info$actionPerformed$9046a9754e643ffd;

// Virtual methods structure
struct _jc_javax_swing_text_StyledEditorKit__24FontSizeAction$vmethods {
	void	(*actionPerformed$9046a9754e643ffd)(_jc_env *, struct _jc_javax_swing_text_StyledEditorKit__24FontSizeAction$object *, struct _jc_java_awt_event_ActionEvent$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_text_StyledEditorKit__24FontSizeAction$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_AbstractAction$vmethods	javax_swing_AbstractAction;
	_jc_javax_swing_text_TextAction$vmethods	javax_swing_text_TextAction;
	_jc_javax_swing_text_StyledEditorKit__24StyledTextAction$vmethods	javax_swing_text_StyledEditorKit__24StyledTextAction;
	_jc_javax_swing_text_StyledEditorKit__24FontSizeAction$vmethods	javax_swing_text_StyledEditorKit__24FontSizeAction;
};

// Vtype
struct _jc_javax_swing_text_StyledEditorKit__24FontSizeAction$vtype {
	_jc_type			type;
	_jc_javax_swing_text_StyledEditorKit__24FontSizeAction$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_text_StyledEditorKit__24FontSizeAction$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_text_StyledEditorKit__24FontSizeAction$refs {
    _jc_javax_swing_text_StyledEditorKit__24FontSizeAction$sub_refs	javax_swing_text_StyledEditorKit__24FontSizeAction;
    _jc_javax_swing_text_StyledEditorKit__24StyledTextAction$sub_refs	javax_swing_text_StyledEditorKit__24StyledTextAction;
    _jc_javax_swing_text_TextAction$sub_refs	javax_swing_text_TextAction;
    _jc_javax_swing_AbstractAction$sub_refs	javax_swing_AbstractAction;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_text_StyledEditorKit__24FontSizeAction$sub_nonrefs {
	jint	size;
};

// Non-reference instance fields (object)
struct _jc_javax_swing_text_StyledEditorKit__24FontSizeAction$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_AbstractAction$sub_nonrefs	javax_swing_AbstractAction;
    _jc_javax_swing_text_TextAction$sub_nonrefs	javax_swing_text_TextAction;
    _jc_javax_swing_text_StyledEditorKit__24StyledTextAction$sub_nonrefs	javax_swing_text_StyledEditorKit__24StyledTextAction;
    _jc_javax_swing_text_StyledEditorKit__24FontSizeAction$sub_nonrefs	javax_swing_text_StyledEditorKit__24FontSizeAction;
};

// Object instance structure
struct _jc_javax_swing_text_StyledEditorKit__24FontSizeAction$object {
	_jc_javax_swing_text_StyledEditorKit__24FontSizeAction$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_text_StyledEditorKit__24FontSizeAction$vtype	*vtype;
	_jc_javax_swing_text_StyledEditorKit__24FontSizeAction$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_text_StyledEditorKit__24FontSizeAction$vtype _jc_javax_swing_text_StyledEditorKit__24FontSizeAction$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_text_StyledEditorKit__24FontSizeAction, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_text_StyledEditorKit__24FontSizeAction$class_object;

#endif	/* _JC_javax_swing_text_StyledEditorKit__24FontSizeAction_H_ */
